<?php

function devcorner_events_create_posttype()
{
  register_post_type( 'events',
        array(
            'labels' => array(
                'name' => __( 'Events' ),
                'singular_name' => __( 'Event' )
            ),
            'public' => true,
            'has_archive' => true,
            //'rewrite' => array('slug' => 'events'),
            'supports' => array( 'title', 'editor', 'excerpt' ),
            'register_meta_box_cb' => 'devcorner_events_metaboxes'
        )
    );
}

add_action( 'init', 'devcorner_events_create_posttype' );


function devcorner_events_metaboxes()
{
	add_meta_box('devcorner_events_location', 'Event Location', 'devcorner_events_location', 'events', 'normal', 'default');
  add_meta_box('devcorner_events_date', 'Event Date', 'devcorner_events_date', 'events', 'side', 'default');
  add_meta_box('devcorner_events_time', 'Event Time', 'devcorner_events_time', 'events', 'side', 'default');
}


function devcorner_events_location()
{
	global $post;
	$value = get_post_meta($post->ID, '_location', true);
	echo '<input type="text" name="_location" value="' . $value  . '" class="widefat" />';
}

function devcorner_events_date()
{
	global $post;
	$value = get_post_meta($post->ID, '_date', true);
	echo '<input type="date" name="_date" value="' . $value  . '" class="widefat" />';
}

function devcorner_events_time()
{
	global $post;
	$value = get_post_meta($post->ID, '_time', true);
	echo '<input type="time" name="_time" value="' . $value  . '" class="widefat" />';

  wp_nonce_field( plugin_basename(__FILE__), 'eventmeta_field' );
}


function devcorner_events_save_meta($post_id, $post)
{
	if (isset($_POST['eventmeta_field'])) {

		// sprawdzamy upoważnienie do zapisania danych
		if (!wp_verify_nonce($_POST['eventmeta_field'], plugin_basename(__FILE__))) {
			return $post->ID;
		}

		// upewniamy się, że użytkownik może edytować post
		if (!current_user_can('edit_post', $post->ID)) return $post->ID;

		// dodajemy wartości do tablicy
		$events_meta['_location'] = $_POST['_location'];
		$events_meta['_date'] = $_POST['_date'];
		$events_meta['_time'] = $_POST['_time'];

		foreach($events_meta as $key => $value) { // pętla
			if ($post->post_type == 'revision') return; // unikamy podwójnego zapisania
			if (get_post_meta($post->ID, $key, FALSE)) { // jeśli pole posiada już wartość, to aktualizujemy
				update_post_meta($post->ID, $key, $value);


			}
			else { // jeśli pole nie posiada wartości, to dodajemy
				add_post_meta($post->ID, $key, $value);
			}

			if (!$value) delete_post_meta($post->ID, $key); // jeśli wartość jest pusta, to usuwamy pole
		}
	}
}

add_action('save_post', 'devcorner_events_save_meta', 1, 2);

function devcorner_events_add_settings_page() {
   add_submenu_page('edit.php?post_type=events', 'Devcorner Events Settings',
                  'Settings', 'manage_options', 'devcorner_events_settings',
                  'devcorner_events_settings_content');
}

add_action('admin_menu', 'devcorner_events_add_settings_page');



function devcorner_events_settings_content() {
  if(! current_user_can('manage_options')) {
    wp_die(__('Nie posiadasz wystarczających uprawnień.'));
  }


  if($_REQUEST['action'] == 'save') {

      update_option('devcorner_events_hover', $_REQUEST['devcorner_events_hover']);
      update_option('devcorner_events_text_color', $_REQUEST['devcorner_events_text_color']);
      update_option('devcorner_events_amount', $_REQUEST['devcorner_events_amount']);

      ?>
        <div class="notice updated">
          <p>Zmiany zostały zapisane.</p>
        </div>
      <?php

  }

  ?>

    <div class="devcorner-events-options-wrapper">
      <form class="wrap devcorner-events-options" method="post">
        <h2>Ustawienia wtyczki Devcorner Events</h2>
        <div class="devcorner-events-options-header postbox">


          <h3>Właściwości wtyczki</h3>
          <p>Tutaj możesz zmodyfikować właściwości wtyczki.</p>

          <table class="devcorner-events-widget-styles">
            <tbody>
              <tr>
                <th scope="row">
                  <label for="devcorner_events_amount">Ilość wydarzeń</label>
                </th>
                <th scope="row">
                  <input type="number" name="devcorner_events_amount" value="<?php echo get_option('devcorner_events_amount'); ?>">
                </th>
              </tr>
            </tbody>
        </table>


            <h3>Style widgetu</h3>
            <p>Tutaj możesz zmodyfikować wygląd widgetu Devcorner Events.</p>

            <table class="devcorner-events-widget-styles">
              <tbody>
                <tr>
                    <th scope="row">
                        <label for="devcorner_events_hover">Efekt hover</label>
                    </th>
                    <td>
                        <fieldset>
                            <label for="none">Brak</label>
                            <input type="radio" value="none" name="devcorner_events_hover" <?php echo get_option( 'devcorner_events_hover')=='none' ? 'checked="checked"' : ''; ?>>
                            <label for="border">Obramowanie</label>
                            <input type="radio" value="border" name="devcorner_events_hover" <?php echo get_option( 'devcorner_events_hover')=='border' ? 'checked="checked"' : ''; ?>>
                        </fieldset>
                    </td>
                </tr>
                <table>
                	<tr>
                		<th scope="row"><label for="devcorner_events_text_color">Kolor tekstu</label>
                		</th>

                		<th scope="row"><input name="devcorner_events_text_color" type="text" value="<?php echo get_option('devcorner_events_text_color'); ?>">
                		</th>
                	</tr>
                </table>
              </tbody>
          </table>

        </div>
        <input type="hidden" name="action" value="save">
        <input type="submit" class="button button-primary" value="Zapisz zmiany">
      </form>
    </div>
  <?php
}
